## Alpa

Another cooL way to PAckage in copr

### Build status

alpa [![Copr build status](https://copr.fedorainfracloud.org/coprs/alpa-team/alpa/package/alpa/status_image/last_build.png)](https://copr.fedorainfracloud.org/coprs/alpa-team/alpa/package/alpa/)

## Table of contents

<!-- toc -->

- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)

<!-- tocstop -->

### Installation

From PyPi:

```bash
$ pip install --user pyalpa
```

From Copr:

```bash
$ dnf copr enable alpa-team/alpa
$ dnf install alpa
```

### Usage

Please visit our [documentation page](https://alpa.readthedocs.io/en/latest) to learn how to use alpa.

### Contributing

TODO
